class Constants {
  static const String kAppName = 'APP_NAME';

  static const bool kEnableWebsockets = true;
  static const String kGraphqlHttpUrl = "HTTPS_URL";
  static const String kGraphqlWsUrl = "WS_URL";
}
